# -*- coding: utf-8 -*-

from django.contrib import admin

from member.models import (GoodsInfo, GoodsOrderInfo, MemberActivityInfo, MemberActivitySigninInfo,
                           MemberActivitySignupInfo, RightInfo, ShotTypeInfo)
from utils.redis.rshot import update_member_shot_data


class GoodsInfoAdmin(admin.ModelAdmin):
    list_display = ('good_id', 'good_type', 'title', 'value', 'left_num', 'coupon_id', 'image', 'is_slider', 'slider_image', 'integral', 'fee', 'minlevel', 'only_for_member', 'position', 'status', 'created_at', 'updated_at')
    list_filter = ('good_type', 'is_slider', 'only_for_member', 'status')


class GoodsOrderInfoAdmin(admin.ModelAdmin):
    list_display = ('order_id', 'user_id', 'good_id', 'good_type', 'title', 'name', 'phone', 'address', 'tracking_number', 'has_send_template_message', 'status', 'created_at', 'updated_at')
    list_filter = ('good_type', 'status')

    def save_model(self, request, obj, form, change):
        obj.save()

        if obj.has_send_template_message:
            return

        if obj.good_type == GoodsInfo.PHYSICAL:
            # TODO: 立即推送模版消息，兑换成功，快递已发送（商品，快递单号，扣除的积分）
            pass


class RightInfoAdmin(admin.ModelAdmin):
    list_display = ('right_id', 'right_type', 'icon', 'title', 'subtitle', 'detail', 'level1', 'level2', 'level3', 'level4', 'level5', 'minlevel', 'position', 'is_send_coupon', 'coupon_num', 'coupon_level1_id', 'coupon_level2_id', 'coupon_level3_id', 'status', 'created_at', 'updated_at')
    list_filter = ('right_type', 'is_send_coupon', 'status')


class ShotTypeInfoAdmin(admin.ModelAdmin):
    list_display = ('shot_type_id', 'shot_type_name', 'position', 'status', 'created_at', 'updated_at')

    def save_model(self, request, obj, form, change):
        obj.save()
        update_member_shot_data()

    def delete_model(self, request, obj):
        obj.delete()
        update_member_shot_data()


class MemberActivityInfoAdmin(admin.ModelAdmin):
    list_display = ('activity_id', 'title', 'subtitle', 'date', 'city', 'location', 'lat', 'lon', 'image', 'is_slider', 'slider_image', 'position', 'status', 'created_at', 'updated_at')
    list_filter = ('is_slider', 'status')


class MemberActivitySignupInfoAdmin(admin.ModelAdmin):
    list_display = ('signup_id', 'activity_id', 'title', 'name', 'phone', 'status', 'created_at', 'updated_at')


class MemberActivitySignupInfoAdmin(admin.ModelAdmin):
    list_display = ('signup_id', 'user_id', 'activity_id', 'title', 'name', 'phone', 'status', 'created_at', 'updated_at')


class MemberActivitySigninInfoAdmin(admin.ModelAdmin):
    list_display = ('signin_id', 'user_id', 'activity_id', 'title', 'status', 'created_at', 'updated_at')


admin.site.register(GoodsInfo, GoodsInfoAdmin)
admin.site.register(GoodsOrderInfo, GoodsOrderInfoAdmin)
admin.site.register(RightInfo, RightInfoAdmin)
admin.site.register(ShotTypeInfo, ShotTypeInfoAdmin)
admin.site.register(MemberActivityInfo, MemberActivityInfoAdmin)
admin.site.register(MemberActivitySignupInfo, MemberActivitySignupInfoAdmin)
admin.site.register(MemberActivitySigninInfo, MemberActivitySigninInfoAdmin)
